@@ -25,24 +25,29 @@
 
 // is this a path of a url svn?
 bool is_svn_url( const std::string &path_or_url )
-	{
-	return svn_path_is_url( path_or_url.c_str() ) != 0;
-	}
+{
+    return svn_path_is_url( path_or_url.c_str() ) != 0;
+}
 
-// convert a path to what SVN likes
+// convert a path or URL to what SVN likes
 std::string svnNormalisedIfPath( const std::string &unnormalised, SvnPool &pool )
-	{
-	if( is_svn_url( unnormalised ) )
-		return unnormalised;
-
-	const char *normalised_path = svn_path_internal_style( unnormalised.c_str(), pool );
-	return std::string( normalised_path );
-	}
+{
+    if( is_svn_url( unnormalised ) )
+    {
+        const char *normalised_path = svn_path_canonicalize( unnormalised.c_str(), pool );
+        return std::string( normalised_path );
+    }
+    else
+    {
+        const char *normalised_path = svn_path_internal_style( unnormalised.c_str(), pool );
+        return std::string( normalised_path );
+    }
+}
 
 // convert a path to what the native OS likes
 std::string osNormalisedPath( const std::string &unnormalised, SvnPool &pool )
-	{
-	const char *local_path = svn_path_local_style( unnormalised.c_str(), pool );
+{
+    const char *local_path = svn_path_local_style( unnormalised.c_str(), pool );
 
-	return std::string( local_path );
-	}
+    return std::string( local_path );
+}
