@@ -151,14 +151,26 @@ SvnContext::SvnContext( const std::string &config_dir_str )
     m_context.auth_baton = auth_baton;
     m_context.log_msg_func = handlerLogMsg;
     m_context.log_msg_baton = this;
-    m_context.notify_func = handlerNotify;
-    m_context.notify_baton = this;
     m_context.cancel_func = handlerCancel;
     m_context.cancel_baton = this;
+#ifdef PYSVN_HAS_CONTEXT_NOTIFY2
+    m_context.notify_func2 = handlerNotify2;
+    m_context.notify_baton2 = this;
+    m_context.notify_func = NULL;
+    m_context.notify_baton = NULL;
+#else
+    m_context.notify_func = handlerNotify;
+    m_context.notify_baton = this;
+#endif
 }
 
 SvnContext::~SvnContext()
 {
+// Why isn't the pool release - object life time problems?
+//    if( m_pool )
+//    {
+//        apr_pool_destroy( m_pool );
+//    }
 }
 
 SvnContext::operator svn_client_ctx_t *()
@@ -171,7 +183,6 @@ svn_client_ctx_t *SvnContext::ctx()
     return &m_context;
 }
 
-
 svn_error_t *SvnContext::handlerLogMsg
     (
     const char **log_msg,
@@ -194,6 +205,19 @@ svn_error_t *SvnContext::handlerLogMsg
     return SVN_NO_ERROR;
 }
 
+#ifdef PYSVN_HAS_CONTEXT_NOTIFY2
+void SvnContext::handlerNotify2
+    (
+    void *baton,
+    const svn_wc_notify_t *notify,
+    apr_pool_t *pool
+    )
+{
+    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+
+    context->contextNotify2( notify, pool );
+}
+#else
 void SvnContext::handlerNotify
     (
     void * baton,
@@ -210,6 +234,7 @@ void SvnContext::handlerNotify
 
     context->contextNotify( path, action, kind, mime_type, content_state, prop_state, revision );
 }
+#endif
 
 svn_error_t *SvnContext::handlerCancel
     (
@@ -354,6 +379,62 @@ svn_error_t *SvnContext::handlerSslClientCertPwPrompt
     return SVN_NO_ERROR;
 }
 
+//--------------------------------------------------------------------------------
+//
+//        SvnTransaction
+//
+//--------------------------------------------------------------------------------
+SvnTransaction::SvnTransaction()
+: m_pool( NULL )
+, m_repos( NULL )
+, m_fs( NULL )
+, m_txn( NULL )
+, m_txn_name( NULL )
+{
+    apr_pool_create( &m_pool, NULL );
+}
+
+svn_error_t *SvnTransaction::init( const std::string &repos_path, const std::string &transaction_name )
+{
+    svn_error_t *error;
+    error = svn_repos_open( &m_repos, repos_path.c_str(), m_pool );
+    if( error != NULL )
+        return error;
+
+    m_fs = svn_repos_fs( m_repos );
+    // what is a warning function?
+    // svn_fs_set_warning_func (m_fs, warning_func, NULL);
+
+    m_txn_name = apr_pstrdup( m_pool, transaction_name.c_str() );
+    error = svn_fs_open_txn( &m_txn, m_fs, m_txn_name, m_pool );
+
+    return error;
+}
+
+SvnTransaction::~SvnTransaction()
+{
+}
+
+SvnTransaction::operator svn_fs_txn_t *()
+{
+    return m_txn;
+}
+
+SvnTransaction::operator svn_fs_t *()
+{
+    return m_fs;
+}
+
+SvnTransaction::operator svn_repos_t *()
+{
+    return m_repos;
+}
+
+
+svn_fs_txn_t *SvnTransaction::transaction()
+{
+    return m_txn;
+}
 
 //--------------------------------------------------------------------------------
 //
@@ -366,6 +447,12 @@ SvnPool::SvnPool( SvnContext &ctx )
     m_pool = svn_pool_create( NULL );
 }
 
+SvnPool::SvnPool( SvnTransaction &txn )
+: m_pool( NULL )
+{
+    m_pool = svn_pool_create( NULL );
+}
+
 SvnPool::~SvnPool()
 {
     if( m_pool != NULL )
@@ -379,7 +466,6 @@ SvnPool::operator apr_pool_t *() const
     return m_pool;
 }
 
-
 static const char *toHex( unsigned int num )
 {
     static char buffer[9];
