@@ -2,12 +2,58 @@
 #define __PYSVN_SVNENV__
 
 #include <svn_client.h>
+#include <svn_fs.h>
+#include <svn_repos.h>
 #include <string>
 
+#if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 1) || SVN_VER_MAJOR > 1
+#define PYSVN_HAS_CLIENT_ADD2
+#define PYSVN_HAS_CLIENT_DIFF_PEG
+#define PYSVN_HAS_CLIENT_EXPORT2
+#define PYSVN_HAS_CLIENT_MERGE_PEG
+#define PYSVN_HAS_CLIENT_VERSION
+#endif
+
+#if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 2) || SVN_VER_MAJOR > 1
+#define PYSVN_HAS_CLIENT_ANNOTATE2
+#define PYSVN_HAS_CLIENT_CAT2
+#define PYSVN_HAS_CLIENT_CHECKOUT2
+#define PYSVN_HAS_CLIENT_DIFF_PEG2
+#define PYSVN_HAS_CLIENT_DIFF2
+#define PYSVN_HAS_CLIENT_EXPORT3
+#define PYSVN_HAS_CLIENT_INFO
+#define PYSVN_HAS_CLIENT_LOCK
+#define PYSVN_HAS_CLIENT_LOG2
+#define PYSVN_HAS_CLIENT_LS2
+#define PYSVN_HAS_CLIENT_MOVE2
+#define PYSVN_HAS_CLIENT_PROPGET2
+#define PYSVN_HAS_CLIENT_PROPLIST2
+#define PYSVN_HAS_CLIENT_PROPSET2
+#define PYSVN_HAS_CLIENT_STATUS2
+#define PYSVN_HAS_CLIENT_UPDATE2
+#define PYSVN_HAS_CONTEXT_NOTIFY2
+#endif
+
+#ifdef PYSVN_HAS_CLIENT_STATUS2
+typedef svn_wc_status2_t pysvn_wc_status_t;
+#else
+typedef svn_wc_status_t pysvn_wc_status_t;
+#endif
+
 #include "CXX/Objects.hxx"
 
+#ifndef PYCXX_MAKEVERSION
+#error PyCXX version 5.3.3 is required
+#endif
+
+#if PYCXX_VERSION < PYCXX_MAKEVERSION( 5, 3, 3 )
+#error PyCXX version 5.3.3 is required
+#endif
+
+
 class SvnPool;
 class SvnContext;
+class SvnTransaction;
 
 class SvnException
 {
@@ -37,6 +83,7 @@ class SvnPool
 {
 public:
     SvnPool( SvnContext &ctx );
+    SvnPool( SvnTransaction &txn );
     ~SvnPool();
 
     operator apr_pool_t *() const;
@@ -49,7 +96,7 @@ class SvnContext
 {
 public:
     SvnContext( const std::string &config_dir="" );
-    ~SvnContext();
+    virtual ~SvnContext();
 
     operator svn_client_ctx_t *();
     svn_client_ctx_t *ctx();
@@ -75,6 +122,13 @@ public:
     // this method will be called to notify about
     // the progress of an ongoing action
     //
+#ifdef PYSVN_HAS_CONTEXT_NOTIFY2
+    virtual void contextNotify2
+        (
+        const svn_wc_notify_t *notify,
+        apr_pool_t *pool
+        ) = 0;
+#else
     virtual void contextNotify
         (
         const char *path,
@@ -85,6 +139,7 @@ public:
         svn_wc_notify_state_t prop_state,
         svn_revnum_t revision
         ) = 0;
+#endif
 
     //
     // this method will be called periodically to allow
@@ -116,7 +171,7 @@ public:
     virtual bool contextSslServerTrustPrompt
         (
         const svn_auth_ssl_server_cert_info_t &info, 
-	const std::string &relam,
+        const std::string &relam,
         apr_uint32_t & acceptedFailures,
         bool &accept_permanent
         ) = 0;
@@ -153,6 +208,14 @@ private:
         apr_pool_t *pool
         );
 
+#ifdef PYSVN_HAS_CONTEXT_NOTIFY2
+    static void SvnContext::handlerNotify2
+        (
+        void * baton,
+	const svn_wc_notify_t *notify,
+	apr_pool_t *pool        
+        );
+#else
     static void SvnContext::handlerNotify
         (
         void * baton,
@@ -164,7 +227,7 @@ private:
         svn_wc_notify_state_t prop_state,
         svn_revnum_t revision
         );
-
+#endif
     static svn_error_t *SvnContext::handlerCancel
         (
         void * baton
@@ -213,4 +276,25 @@ private:
     svn_client_ctx_t    m_context;
 };
 
+class SvnTransaction
+{
+public:
+    SvnTransaction();
+    ~SvnTransaction();
+
+    svn_error_t *init( const std::string &repos_path, const std::string &transaction );
+
+    operator svn_fs_txn_t *();
+    svn_fs_txn_t *transaction();
+    operator svn_fs_t *();
+    operator svn_repos_t *();
+
+private:
+    apr_pool_t          *m_pool;
+    svn_repos_t         *m_repos;
+    svn_fs_t            *m_fs;
+    svn_fs_txn_t        *m_txn;
+    char                *m_txn_name;
+};
+
 #endif // __PYSVN_SVNENV__
